pub(crate) struct ReusableBoxFuture<T> {
boxed: NonNull<dyn Future<Output = T> + Send>,
}Expand description
A reusable Pin<Box<dyn Future<Output = T> + Send>>.
This type lets you replace the future stored in the box without reallocating when the size and alignment permits this.
Fields
boxed: NonNull<dyn Future<Output = T> + Send>Implementations
Sourceimpl<T> ReusableBoxFuture<T>
impl<T> ReusableBoxFuture<T>
Sourcepub(crate) fn new<F>(future: F) -> Self
pub(crate) fn new<F>(future: F) -> Self
Create a new ReusableBoxFuture<T> containing the provided future.
Sourcepub(crate) fn set<F>(&mut self, future: F)
pub(crate) fn set<F>(&mut self, future: F)
Replaces the future currently stored in this box.
This reallocates if and only if the layout of the provided future is different from the layout of the currently stored future.
Sourcepub(crate) fn try_set<F>(&mut self, future: F) -> Result<(), F>
pub(crate) fn try_set<F>(&mut self, future: F) -> Result<(), F>
Replaces the future currently stored in this box.
This function never reallocates, but returns an error if the provided future has a different size or alignment from the currently stored future.
Sourceunsafe fn set_same_layout<F>(&mut self, future: F)
unsafe fn set_same_layout<F>(&mut self, future: F)
Sets the current future.
Safety
This function requires that the layout of the provided future is the
same as self.layout.